package com.aitrainer.api.controller

import com.aitrainer.api.model.Exercises
import com.aitrainer.api.repository.ExercisesRepository
import org.springframework.http.ResponseEntity
import org.springframework.web.bind.annotation.*
import javax.validation.Valid

class ExerciesController(private val exercisesRepository: ExercisesRepository) {

    @GetMapping("/exercises/customer/{id}")
    fun getAllExersicesByCustomerId(customerId: Long): List<Exercises> =
            exercisesRepository.getAllByCustomerId(customerId)

    @PostMapping("/exercises")
    fun createNewExercise(@Valid @RequestBody exercises: Exercises): Exercises =
            exercisesRepository.save(exercises)

    @PutMapping("/exercises/{id}")
    fun updateExerciseById(@PathVariable(value = "id") exerciseId: Long,
                           @Valid @RequestBody newExercises: Exercises): ResponseEntity<Exercises> {
        return exercisesRepository.findById(exerciseId).map { existingExercises ->
            val updatedExercises: Exercises = existingExercises.copy(
                    exerciseTypeId = newExercises.exerciseTypeId,
                    customerId = newExercises.customerId,
                    datetimeExercise = newExercises.datetimeExercise,
                    quantity = newExercises.quantity,
                    restTime = newExercises.restTime
            )
            ResponseEntity.ok().body(exercisesRepository.save(updatedExercises))
        }.orElse(ResponseEntity.notFound().build())
    }
}